@@ -9,7 +9,9 @@
 #' @return A matrix providing the type-specific prediction accuracy index that corresponds to the set differential risk hotspots obtained for each value of \code{k} or \code{n} provided in \code{ks} and \code{ns}, respectively. A \code{NA} value in this matrix indicates that no differential risk hotspots are found for the corresponding combination of \code{k} and \code{n}
 #' @examples 
 #' library(DRHotNet)
-#' library(spatstat)
+#' library(spatstat.core)
+#' library(spatstat.geom)
+#' library(spatstat.linnet)
 #' library(spdep)
 #' library(raster)
 #' library(maptools)
@@ -26,24 +28,24 @@ Sensitivity_k_n <- function(X,rel_probs,ks,ns){
   network=X$domain
   
   if (rel_probs$lixel_length!=F){
-    network=lixellate(network,eps=rel_probs$lixel_length)
+    network=spatstat.linnet::lixellate(network,eps=rel_probs$lixel_length)
     #& project into the new network
-    X_aux=lpp(cbind(X$data$x,X$data$y),network)
-    marks(X_aux)=marks(X)
+    X_aux=spatstat.linnet::lpp(cbind(X$data$x,X$data$y),network)
+    spatstat.geom::marks(X_aux)=spatstat.geom::marks(X)
     X=X_aux
   }
   network_lix=X$domain
-  midpoints=midpoints.psp(as.psp(network_lix))
-  segment_lengths=lengths.psp(as.psp(network_lix))
+  midpoints=spatstat.geom::midpoints.psp(spatstat.geom::as.psp(network_lix))
+  segment_lengths=spatstat.geom::lengths_psp(spatstat.geom::as.psp(network_lix))
   
   # Midpoints as a point pattern (on the original network)
-  lpp_midpoints=lpp(midpoints,network)
+  lpp_midpoints=spatstat.linnet::lpp(midpoints,network)
 
   PAIs=matrix(NA,nrow=length(ks),ncol=length(ns))
   for (i in 1:length(ks)){
     # Compute distances between the middle points of those segments satisfying condition on k
     sig=which(rel_probs$probs>=mean(rel_probs$probs)+ks[i]*sd(rel_probs$probs))
-    distances=crossdist.lpp(lpp_midpoints[sig,],X)
+    distances=spatstat.linnet::crossdist.lpp(lpp_midpoints[sig,],X)
     for (j in 1:length(ns)){
       cat(paste0("k = ",ks[i],", n = ",ns[j]),"\n")
       hotspots=DRHotspots_k_n(X,rel_probs,ks[i],ns[j],event_distances=distances)
@@ -55,4 +57,4 @@ Sensitivity_k_n <- function(X,rel_probs,ks,ns){
   rownames(PAIs)=paste0("k = ",ks)
   colnames(PAIs)=paste0("n = ",ns)
   return(PAIs)
-}
\ No newline at end of file
+}
